@@ -21,12 +21,12 @@ use crate::signal::Waiter;
 use crate::util::HeaderList;
 
 fn parse_hash<T: Hash>(value: &Value) -> Result<T> {
-    Ok(T::from_hex(
+    T::from_hex(
         value
             .as_str()
             .chain_err(|| format!("non-string value: {}", value))?,
     )
-    .chain_err(|| format!("non-hex value: {}", value))?)
+    .chain_err(|| format!("non-hex value: {}", value))
 }
 
 fn header_from_value(value: Value) -> Result<BlockHeader> {
@@ -34,22 +34,20 @@ fn header_from_value(value: Value) -> Result<BlockHeader> {
         .as_str()
         .chain_err(|| format!("non-string header: {}", value))?;
     let header_bytes = hex::decode(header_hex).chain_err(|| "non-hex header")?;
-    Ok(
-        deserialize(&header_bytes)
-            .chain_err(|| format!("failed to parse header {}", header_hex))?,
-    )
+
+    deserialize(&header_bytes).chain_err(|| format!("failed to parse header {}", header_hex))
 }
 
 fn block_from_value(value: Value) -> Result<Block> {
     let block_hex = value.as_str().chain_err(|| "non-string block")?;
     let block_bytes = hex::decode(block_hex).chain_err(|| "non-hex block")?;
-    Ok(deserialize(&block_bytes).chain_err(|| format!("failed to parse block {}", block_hex))?)
+    deserialize(&block_bytes).chain_err(|| format!("failed to parse block {}", block_hex))
 }
 
 fn tx_from_value(value: Value) -> Result<Transaction> {
     let tx_hex = value.as_str().chain_err(|| "non-string tx")?;
     let tx_bytes = hex::decode(tx_hex).chain_err(|| "non-hex tx")?;
-    Ok(deserialize(&tx_bytes).chain_err(|| format!("failed to parse tx {}", tx_hex))?)
+    deserialize(&tx_bytes).chain_err(|| format!("failed to parse tx {}", tx_hex))
 }
 
 /// Parse JSONRPC error code, if exists.
@@ -451,12 +449,12 @@ impl Daemon {
 
     fn getblockchaininfo(&self) -> Result<BlockchainInfo> {
         let info: Value = self.request("getblockchaininfo", json!([]))?;
-        Ok(from_value(info).chain_err(|| "invalid blockchain info")?)
+        from_value(info).chain_err(|| "invalid blockchain info")
     }
 
     fn getnetworkinfo(&self) -> Result<NetworkInfo> {
         let info: Value = self.request("getnetworkinfo", json!([]))?;
-        Ok(from_value(info).chain_err(|| "invalid network info")?)
+        from_value(info).chain_err(|| "invalid network info")
     }
 
     pub fn get_subversion(&self) -> Result<String> {
@@ -513,7 +511,7 @@ impl Daemon {
 
     pub fn getblocktxids(&self, blockhash: &BlockHash) -> Result<Vec<Txid>> {
         self.blocktxids_cache
-            .get_or_else(&blockhash, || self.load_blocktxids(blockhash))
+            .get_or_else(blockhash, || self.load_blocktxids(blockhash))
     }
 
     pub fn gettransaction(
@@ -538,14 +536,14 @@ impl Daemon {
         if let Some(blockhash) = blockhash {
             args.as_array_mut().unwrap().push(json!(blockhash.to_hex()));
         }
-        Ok(self.request("getrawtransaction", args)?)
+        self.request("getrawtransaction", args)
     }
 
     pub fn getmempooltxids(&self) -> Result<HashSet<Txid>> {
         let txids: Value = self.request("getrawmempool", json!([/*verbose=*/ false]))?;
         let mut result = HashSet::new();
         for value in txids.as_array().chain_err(|| "non-array result")? {
-            result.insert(parse_hash(&value).chain_err(|| "invalid txid")?);
+            result.insert(parse_hash(value).chain_err(|| "invalid txid")?);
         }
         Ok(result)
     }
@@ -570,10 +568,8 @@ impl Daemon {
     pub fn broadcast(&self, tx: &Transaction) -> Result<Txid> {
         let tx = hex::encode(serialize(tx));
         let txid = self.request("sendrawtransaction", json!([tx]))?;
-        Ok(
-            Txid::from_hex(txid.as_str().chain_err(|| "non-string txid")?)
-                .chain_err(|| "failed to parse txid")?,
-        )
+        Txid::from_hex(txid.as_str().chain_err(|| "non-string txid")?)
+            .chain_err(|| "failed to parse txid")
     }
 
     fn get_all_headers(&self, tip: &BlockHash) -> Result<Vec<BlockHeader>> {
@@ -589,7 +585,7 @@ impl Daemon {
         let null_hash = BlockHash::default();
         for heights in all_heights.chunks(chunk_size) {
             trace!("downloading {} block headers", heights.len());
-            let mut headers = self.getblockheaders(&heights)?;
+            let mut headers = self.getblockheaders(heights)?;
             assert!(headers.len() == heights.len());
             result.append(&mut headers);
         }
