@@ -319,7 +319,7 @@ impl Connection {
             Some(value) => value.as_bool().chain_err(|| "non-bool verbose value")?,
             None => false,
         };
-        Ok(self.query.get_transaction(&tx_hash, verbose)?)
+        self.query.get_transaction(&tx_hash, verbose)
     }
 
     fn blockchain_transaction_get_confirmed_blockhash(&self, params: &[Value]) -> Result<Value> {
@@ -367,24 +367,22 @@ impl Connection {
             .with_label_values(&[method])
             .start_timer();
         let result = match method {
-            "blockchain.block.header" => self.blockchain_block_header(&params),
-            "blockchain.block.headers" => self.blockchain_block_headers(&params),
-            "blockchain.estimatefee" => self.blockchain_estimatefee(&params),
+            "blockchain.block.header" => self.blockchain_block_header(params),
+            "blockchain.block.headers" => self.blockchain_block_headers(params),
+            "blockchain.estimatefee" => self.blockchain_estimatefee(params),
             "blockchain.headers.subscribe" => self.blockchain_headers_subscribe(),
             "blockchain.relayfee" => self.blockchain_relayfee(),
-            "blockchain.scripthash.get_balance" => self.blockchain_scripthash_get_balance(&params),
-            "blockchain.scripthash.get_history" => self.blockchain_scripthash_get_history(&params),
-            "blockchain.scripthash.listunspent" => self.blockchain_scripthash_listunspent(&params),
-            "blockchain.scripthash.subscribe" => self.blockchain_scripthash_subscribe(&params),
-            "blockchain.transaction.broadcast" => self.blockchain_transaction_broadcast(&params),
-            "blockchain.transaction.get" => self.blockchain_transaction_get(&params),
-            "blockchain.transaction.get_merkle" => self.blockchain_transaction_get_merkle(&params),
+            "blockchain.scripthash.get_balance" => self.blockchain_scripthash_get_balance(params),
+            "blockchain.scripthash.get_history" => self.blockchain_scripthash_get_history(params),
+            "blockchain.scripthash.listunspent" => self.blockchain_scripthash_listunspent(params),
+            "blockchain.scripthash.subscribe" => self.blockchain_scripthash_subscribe(params),
+            "blockchain.transaction.broadcast" => self.blockchain_transaction_broadcast(params),
+            "blockchain.transaction.get" => self.blockchain_transaction_get(params),
+            "blockchain.transaction.get_merkle" => self.blockchain_transaction_get_merkle(params),
             "blockchain.transaction.get_confirmed_blockhash" => {
-                self.blockchain_transaction_get_confirmed_blockhash(&params)
-            }
-            "blockchain.transaction.id_from_pos" => {
-                self.blockchain_transaction_id_from_pos(&params)
+                self.blockchain_transaction_get_confirmed_blockhash(params)
             }
+            "blockchain.transaction.id_from_pos" => self.blockchain_transaction_id_from_pos(params),
             "mempool.get_fee_histogram" => self.mempool_get_fee_histogram(),
             "server.banner" => self.server_banner(),
             "server.donation_address" => self.server_donation_address(),
